/// <reference types="node" />
import { TSessionStore, TXmlParser, TErrorHandler, TWall, TShield, TGuard } from "../types";
import { ViewEngine, ResultMapper, ComponentOption } from "../abstracts";
import * as http from "http";
import { Logger } from "./logger";
import { IDtoValidator, IEtagOption, IFolderMap, IControllerRoute } from "../interfaces";
export declare class Fort {
    static set logger(value: Logger);
    static get logger(): Logger;
    static set walls(walls: TWall[]);
    static get walls(): TWall[];
    static set shields(shields: TShield[]);
    static set guards(guards: TGuard[]);
    /**
     * port at which app will listen, default - 4000
     *
     * @static
     * @memberof Fort
     */
    static set port(value: number);
    static get port(): number;
    /**
     * typeof ErrorHandler
     *
     * @static
     * @memberof Fort
     */
    static set errorHandler(value: TErrorHandler);
    static set routes(value: IControllerRoute[]);
    /**
     * view engine use to render the view
     *
     * @static
     * @memberof Fort
     */
    static set viewEngine(value: typeof ViewEngine);
    /**
     * sessionStore class, default - MemorySessionStore
     *
     * @static
     * @memberof Fort
     */
    static set sessionStore(value: TSessionStore);
    static set resultMapper(value: typeof ResultMapper);
    /**
     * XmlParser class - used to parse the xml
     *
     * @static
     * @memberof Fort
     */
    static set xmlParser(xmlParser: TXmlParser);
    /**
     * Whether to parse cookie or not, default - true
     * If false, then session wont work.
     *
     * @static
     * @memberof Fort
     */
    static set shouldParseCookie(value: boolean);
    /**
     * Whether to parse the http body data in post request, default - true
     *
     * @static
     * @memberof Fort
     */
    static set shouldParseBody(value: boolean);
    /**
     * session timeout in minute - default is 60 minute
     *
     * @static
     * @memberof Fort
     */
    static set sessionTimeOut(value: number);
    /**
     * name of application - default is fort. Visible in header and cookie.
     * Change name if you dont want any one to know the framework name.
     *
     * @static
     * @memberof Fort
     */
    static set appName(value: string);
    /**
     * Views folder location. By default it is - views.
     *
     * @static
     * @memberof Fort
     */
    static set viewPath(value: string);
    static set componentOption(value: typeof ComponentOption);
    static get httpServer(): http.Server;
    static set httpServer(value: http.Server);
    /**
     * folders which should be visible to requests. By default nothing is allowed.
     *
     * @static
     * @memberof Fort
     */
    static set folders(value: IFolderMap[]);
    /**
     * eTag Settings
     *
     * @static
     * @memberof Fort
     */
    static set eTag(value: IEtagOption);
    static instance: Fort;
    private constructor();
    private httpServer;
    static create(): Promise<void>;
    static onNewRequest(request: any, response: any): void;
    static destroy(): Promise<void>;
    static set validator(validator: IDtoValidator);
}
